# seafood
Shellcommands:
Utilities for shell commands and sub processes in windows and unix.

Povray:
Wrapper for povray wrapper vapory. Make sure to set environment variable in windows systems. See vapory installation.
For some functionalities include the analytical_g.inc file within your includes folder of povray.